EditMultilinearInfo

Struct EditMultilinearInfo 

pub struct EditMultilinearInfo<'a> { /* private fields */ }
A wrapper type for MultilinearInfo which only supports safe edits that don’t invalidate existing simulation states.

Implementations

Source

impl<'a> EditMultilinearInfo<'a>

pub fn add_aspect(&mut self) -> Aspect

Adds a new aspect to the multilinear system and returns its identifier.

pub fn add_event(&mut self) -> EventEdit<'_>

Adds a new event to the multilinear system and returns an editable event info.

pub fn add_event_with_changes( &mut self, changes: &[&[Change]], ) -> Result<EventEdit<'_>, InvalidChangeError>

Adds a new event with multiple change sets and returns the editable event info.

Errors

Returns InvalidChangeError if any change set duplicates an aspect or conflicts with an earlier change set on this event.

Methods from Deref<Target = MultilinearInfo>

pub fn iter(&self) -> impl Iterator<Item = (Event, &EventNode)>

Returns an iterator over the events and the event nodes containing the changes.